==> manaplus-1.1.3.20.tar.bz2: manaplus/src/gui/specialswindow.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SPECIALSWINDOW_H
#define SPECIALSWINDOW_H

#include <vector>

#include "guichanfwd.h"

#include "playerinfo.h"

#include "gui/widgets/window.h"

#include <guichan/actionlistener.hpp>

#include <map>

#ifdef __GNUC__
#define _UNUSED_  __attribute__ ((unused))
#else
#define _UNUSED_
#endif

class Label;
class ScrollArea;
class Tab;
class TabbedArea;

struct SpecialEntry;

class SpecialsWindow : public Window, public gcn::ActionListener
{
    public:
        SpecialsWindow();

        ~SpecialsWindow();

        /**
         * Called when receiving actions from widget.
         */
        void action(const gcn::ActionEvent &actionEvent);

        void draw(gcn::Graphics *graphics);

    private:
        // (re)constructs the list of specials
        void rebuild(const std::map<int, Special> &specialData);

        TabbedArea *mTabs;
        std::map<int, SpecialEntry *> mEntries;
};

extern SpecialsWindow *specialsWindow;

#endif // SPECIALSWINDOW_H

==> manaplus-1.1.8.21.tar.bz2: manaplus/src/gui/specialswindow.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SPECIALSWINDOW_H
#define SPECIALSWINDOW_H

#include <vector>

#include "guichanfwd.h"

#include "playerinfo.h"

#include "gui/widgets/window.h"

#include <guichan/actionlistener.hpp>

#include <map>

#ifdef __GNUC__
#define A_UNUSED  __attribute__ ((unused))
#else
#define A_UNUSED
#endif

class Label;
class ScrollArea;
class Tab;
class TabbedArea;

class SpecialEntry;

class SpecialsWindow : public Window, public gcn::ActionListener
{
    public:
        SpecialsWindow();

        ~SpecialsWindow();

        /**
         * Called when receiving actions from widget.
         */
        void action(const gcn::ActionEvent &actionEvent);

        void draw(gcn::Graphics *graphics);

    private:
        // (re)constructs the list of specials
        void rebuild(const std::map<int, Special> &specialData);

        TabbedArea *mTabs;
        std::map<int, SpecialEntry *> mEntries;
};

extern SpecialsWindow *specialsWindow;

#endif // SPECIALSWINDOW_H
